<template>
  <div class="departmental-statistics-processing-status">
    <public-title title="部门统计办理状态">
      <template v-slot:title-end>
        <van-icon name="search" size="19" color="#5e9df0" @click="showPopup('querySearchPopup')" />
      </template>
    </public-title>
    <div class="chart-container">
      <div id="departmental-statistics-processing-status-chart" style="width: 100%;height: 100%;" />
    </div>

    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="queryParams"
      @searchData="searchData"
    />
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {
  statisticsDeptHandleStatus as echartsInterface
} from '@/api/Mobile/leadershipKanban'
import PublicTitle from '../PublicTitle/index.vue'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'

export default {
  name: 'DepartmentalStatisticsProcessingStatus', // 部门统计办理状态
  components: {QuerySearchPopup, PublicTitle},
  data() {
    return {
      queryParams: {
        dateTime: ''
      },
      myChart: null,  // 图表实例对象
      chartData: {},
      querySearchPopup: false
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('departmental-statistics-processing-status-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    async getChartData() {
      this.chartData = await echartsInterface(this.queryParams)
      this.$nextTick(_ => this.initEcharts())
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        tooltip: {
          trigger: 'axis',
          textStyle: {  //---提示框样式
            color: '#606266',
            fontSize: '10'
          },
          axisPointer: {            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
          }
        },
        legend: {
          type: 'plain',
          position: 'center',
          textStyle: {  //---提示框样式
            color: '#606266',
            fontSize: '10'
          }
        },
        grid: {
          left: '0',
          right: '0',
          bottom: '30',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            axisTick: {show: true},
            axisLabel: {color: '#606266', fontSize: '10'},
            data: this.chartData.map(i => i.deptName)
          }
        ],
        yAxis: [
          {
            type: 'value',
            name: '单位（件数）',
            nameTextStyle: {
              color: '#606266',
              fontSize: '10',
              align: 'end',
              padding: [0, 0, 0, -10]
            },
            nameGap: 30,
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {color: '#606266', fontSize: '10'},
            // 修改y轴分割线
            splitLine: {
              lineStyle: {
                color: '#c7c7c7',
                fontSize: '10',
                type: 'dashed'
              }
            }
          }
        ],
        series: [
          {
            name: '待处置',
            type: 'bar',
            barGap: '20%',
            barWidth: '15',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#ffda68'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#ffda68',//字体颜色
                fontSize: 10//字体大小
              }
            },
            data: this.chartData.map(i => i.waitHandle)
          },
          {
            name: '处置中',
            type: 'bar',
            barGap: '20%',
            barWidth: '15',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#3eadfd'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#3eadfd',//字体颜色
                fontSize: 10//字体大小
              }
            },
            data: this.chartData.map(i => i.finished)
          },
          {
            name: '处置完成',
            type: 'bar',
            barGap: '20%',
            barWidth: '15',
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#68faa3'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => value ? value : '',
              textStyle: { //数值样式
                color: '#68faa3',//字体颜色
                fontSize: 10//字体大小
              }
            },
            data: this.chartData.map(i => i.handleeing)
          }
        ],
        dataZoom: [
          {
            type: 'slider',
            show: true,
            start: 0,//默认为0
            end: 65,//默认为100
            xAxisIndex: [0],
            handleSize: 0,//滑动条的 左右2个滑动条的大小
            height: 20,//组件高度
            bottom: 0,//右边的距离
            borderColor: '#e3e3e3',
            fillerColor: '#51B7F9',
            borderRadius: 10,
            backgroundColor: '#e3e3e3',//两边未选中的滑动条区域的颜色
            showDataShadow: false,//是否显示数据阴影 默认auto
            showDetail: false,//即拖拽时候是否显示详细数值信息 默认true
            realtime: true, //是否实时更新
            filterMode: 'filter',
            zlevel: -10
          },
          //以下重点： 让鼠标滚动从缩放变成移动
          {
            type: 'inside',
            xAxisIndex: [0],
            zoomOnMouseWheel: false, //滚轮不触发缩放
            moveOnMouseMove: true,   //鼠标移动触发平移
            moveOnMouseWheel: true  //鼠标滚轮触发平移
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    },

    // 查询/重置按钮点击
    searchData() {
      this.getChartData()
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.departmental-statistics-processing-status {
  width: 100%;
  min-height: 300PX;
  display: flex;
  flex-direction: column;
  box-shadow: 0 10px 15px 0 rgba(0, 0, 0, 0.1), 0 10px 25px 0 rgba(0, 0, 0, 0.1);
  border-radius: 40px;


  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 40px 60px 60px;

  }
}
</style>
